@@ -27,8 +27,8 @@ use constant DEVEL_MODE => 0;
 
 # CLI options
 # NB: Invalid parameter values (e.g., --format=foo) trigger App::Cmd usage/help
-# This hides the detailed Types::Standard error  
-# Fix by overriding usage_error/options_usage  
+# This hides the detailed Types::Standard error
+# Fix by overriding usage_error/options_usage
 #
 # Example (Types::Standard):
 # perl -Ilib -MClarID::Tools::Command::code -we \
@@ -39,7 +39,7 @@ use constant DEVEL_MODE => 0;
 option entity => (
     is     => 'ro',
     format => 's',
-    isa    => Enum[qw/biosample subject biospecimen individual/],
+    isa    => Enum [qw/biosample subject biospecimen individual/],
     coerce => sub {
         return 'biosample' if $_[0] eq 'biospecimen';
         return 'subject'   if $_[0] eq 'individual';
@@ -52,14 +52,14 @@ option entity => (
 option format => (
     is       => 'ro',
     format   => 's',
-    isa      => Enum[qw/human stub/],
+    isa      => Enum [qw/human stub/],
     doc      => 'human | stub',
     required => 1,
 );
 option action => (
     is       => 'ro',
     format   => 's',
-    isa      => Enum[qw/encode decode/],
+    isa      => Enum [qw/encode decode/],
     doc      => 'encode | decode',
     required => 1,
 );
@@ -475,12 +475,21 @@ sub _run_bulk {
             say $out_fh join( $sep, ( map { $row->{$_} // '' } @$hdr ), $out );
         }
         else {
-            my $id_col = $self->format eq 'stub' ? 'stub_id' : 'clar_id';
+            # enforce column based on --format
+            my ( $meth, $id_col );
+            if ( $self->format eq 'human' ) {
+                $meth   = sprintf '_decode_human_%s', $self->entity;
+                $id_col = 'clar_id';
+            }
+            else {    # format eq 'stub'
+                $meth   = sprintf '_decode_stub_%s', $self->entity;
+                $id_col = 'stub_id';
+            }
+
             croak "Missing $id_col in input row"
               unless defined $row->{$id_col};
 
-            my $meth = sprintf '_decode_%s_%s', $self->format, $self->entity;
-            my $res  = $self->$meth( $cb, $row->{$id_col} );
+            my $res = $self->$meth( $cb, $row->{$id_col} );
 
             my @out = map { $res->{$_} // '' } $self->_decode_fields;
             if ( $self->with_condition_name && $code2name ) {
